import type { Metadata } from "next";
import { Inter as FontSans } from "next/font/google";
import "./globals.css";
import { cn } from "@/lib/utils";
import { Analytics } from "@vercel/analytics/react";
import giteaIcon from "/public/icons/gitea.svg";
import Image from "next/image";

const fontSans = FontSans({
  subsets: ["latin"],
  variable: "--font-sans",
});

export const metadata: Metadata = {
  title: "Junior and Mid-Level Software Engineer Jobs",
  description: "Get the latest job openings from the sw-jobs-api",
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>) {
  return (
    <html lang="en">
      <body
        className={cn(
          "min-h-screen bg-background font-sans antialiased",
          fontSans.variable
        )}
      >
        {children}
        <Analytics />
        <footer className="flex justify-center text-sm text-stone-500 py-4">
          <a href="https://gitea.rannes.dev/christian">
            <Image alt="gitea icon" src={giteaIcon} width={24} height={24} />
          </a>
        </footer>
      </body>
    </html>
  );
}
